document.addEventListener('DOMContentLoaded', function() {
    const updateClock = () => {
        const now = new Date();
        const timeElements = document.querySelectorAll('.liveclock-time');
        const dateElements = document.querySelectorAll('.liveclock-date');

        timeElements.forEach(timeElement => {
            const timeString = now.toLocaleTimeString('en-US', {
                hour: 'numeric',
                minute: '2-digit',
                second: '2-digit',
                hour12: true
            });
            timeElement.textContent = timeString;
        });

        dateElements.forEach(dateElement => {
            const dateString = now.toLocaleDateString('en-US', {
                weekday: 'long',
                year: 'numeric',
                month: 'long',
                day: 'numeric'
            });
            dateElement.textContent = dateString;
        });

        // Apply custom styles if available
        if (typeof liveclockSettings !== 'undefined') {
            const options = liveclockSettings.options;
            const containers = document.querySelectorAll('.liveclock-container');
            
            containers.forEach(container => {
                if (options.font_family) {
                    container.style.fontFamily = options.font_family;
                }
                if (options.text_color) {
                    container.style.color = options.text_color;
                }
                if (options.font_size) {
                    const baseSize = parseInt(options.font_size);
                    container.querySelector('.liveclock-time').style.fontSize = `${baseSize}px`;
                    container.querySelector('.liveclock-date').style.fontSize = `${baseSize * 0.6}px`;
                }
            });
        }
    };

    // Update immediately and then every second
    updateClock();
    setInterval(updateClock, 1000);
});
